@@ -1,14 +1,11 @@
 # type: ignore[attr-defined]
-from typing import Optional
-
 from enum import Enum
-from random import choice
 
 import typer
 from rich.console import Console
 
 from drowsy_server import version
-from drowsy_server.example import hello
+from drowsy_server.interface import show_interface
 
 
 class Color(str, Enum):
@@ -23,7 +20,7 @@ class Color(str, Enum):
 app = typer.Typer(
     name="drowsy_server",
     help="Drowsy Server",
-    add_completion=False,
+    add_completion=True,
 )
 console = Console()
 
@@ -37,15 +34,6 @@ def version_callback(print_version: bool) -> None:
 
 @app.command(name="")
 def main(
-    name: str = typer.Option(..., help="Person to greet."),
-    color: Optional[Color] = typer.Option(
-        None,
-        "-c",
-        "--color",
-        "--colour",
-        case_sensitive=False,
-        help="Color for print. If not specified then choice will be random.",
-    ),
     print_version: bool = typer.Option(
         None,
         "-v",
@@ -55,12 +43,8 @@ def main(
         help="Prints the version of the drowsy_server package.",
     ),
 ) -> None:
-    """Print a greeting with a giving name."""
-    if color is None:
-        color = choice(list(Color))
-
-    greeting: str = hello(name)
-    console.print(f"[bold {color}]{greeting}[/]")
+    """Show the main interface"""
+    show_interface()
 
 
 if __name__ == "__main__":
